@@ -8,14 +8,15 @@ More detailed description.
 import multiprocessing as mp
 import warnings
 
-from pyrasta.crs import proj4_from
+import pyproj
 from pyrasta.io_.files import _copy_to_file
 from pyrasta.tools.calculator import _op, _raster_calculation
 from pyrasta.tools.clip import _clip_raster_by_extent, _clip_raster_by_mask
 from pyrasta.tools.conversion import _resample_raster, _padding, _rescale_raster, \
     _align_raster, _extract_bands, _merge_bands, _read_array, _xy_to_2d_index, _read_value_at, \
-    _project_raster
+    _project_raster, _array_to_raster
 from pyrasta.exceptions import RasterBaseError
+from pyrasta.tools.mask import _raster_mask
 from pyrasta.tools.merge import _merge
 from pyrasta.tools.rasterize import _rasterize
 from pyrasta.tools.stats import _histogram, _zonal_stats
@@ -144,6 +145,13 @@ class RasterBase:
         """
         return _extract_bands(self, bands)
 
+    @classmethod
+    def from_array(cls, array, crs, bounds,
+                   gdal_driver=gdal.GetDriverByName("Gtiff"),
+                   no_data=-999):
+
+        return _array_to_raster(cls, array, crs, bounds, gdal_driver, no_data)
+
     def histogram(self, nb_bins=10, normalized=True):
         """ Compute raster histogram
 
@@ -163,6 +171,34 @@ class RasterBase:
         """
         return _histogram(self, nb_bins, normalized)
 
+    def mask(self, mask, gdal_driver=gdal.GetDriverByName("Gtiff"),
+             data_type=gdal.GetDataTypeByName('Float32'),
+             all_touched=True, no_data=-999, window_size=500):
+        """ Apply mask to raster
+
+        Parameters
+        ----------
+        mask: geopandas.geodataframe or gistools.layer.GeoLayer
+            Mask layer as a GeoDataFrame or GeoLayer
+        gdal_driver: osgeo.gdal.Driver
+            Driver used to write data to file
+        data_type: int
+            GDAL data type
+        all_touched: bool
+            if True, all touched pixels within layer boundaries are burnt,
+            when clipping raster by mask
+        no_data: int or float
+            output no data value in masked raster
+        window_size: int or list[int, int]
+            Size of window for raster calculation
+
+        Returns
+        -------
+
+        """
+        return _raster_mask(self, mask, gdal_driver, data_type,
+                            no_data, all_touched, window_size)
+
     @classmethod
     def merge(cls, rasters, bounds=None, output_format="Gtiff",
               data_type=gdal.GetDataTypeByName('Float32'), no_data=-999):
@@ -285,7 +321,8 @@ class RasterBase:
                            gdal_driver=gdal.GetDriverByName("Gtiff"),
                            data_type=gdal.GetDataTypeByName('Float32'),
                            no_data=-999, nb_processes=mp.cpu_count(),
-                           chunksize=MP_CHUNK_SIZE):
+                           chunksize=MP_CHUNK_SIZE,
+                           description="Calculate raster expression"):
         """ Raster expression calculation
 
         Description
@@ -314,6 +351,8 @@ class RasterBase:
             number of processes for multiprocessing pool
         chunksize: int
             chunk size used in map/imap multiprocessing function
+        description: str
+            Progress bar description
 
         Returns
         -------
@@ -322,7 +361,7 @@ class RasterBase:
         """
         return _raster_calculation(cls, rasters, fhandle, window_size,
                                    gdal_driver, data_type, no_data,
-                                   nb_processes, chunksize)
+                                   nb_processes, chunksize, description)
 
     def read_array(self, band=None, bounds=None):
         """ Write raster to numpy array
@@ -532,7 +571,7 @@ class RasterBase:
         """ Return Coordinate Reference System
 
         """
-        return proj4_from(self._gdal_dataset.GetProjection())
+        return pyproj.CRS(self._gdal_dataset.GetProjection())
 
     @lazyproperty
     def bounds(self):
@@ -587,10 +626,8 @@ class RasterBase:
         """
         return self._gdal_dataset.RasterCount
 
-    @lazyproperty
+    @property
     def no_data(self):
-        # return [self._gdal_dataset.GetRasterBand(band + 1).GetNoDataValue()
-        # for band in range(self.nb_band)]
         return self._gdal_dataset.GetRasterBand(1).GetNoDataValue()
 
     @lazyproperty
